var callbackMap = new Map()
var apiLevel = -1
function getApiLevel() {
    if (apiLevel == -1) {
        apiLevel = TTJSBridge.invoke("tgame_engine", "getEngineApiLevel")
        try {
            apiLevel = parseInt(apiLevel)
        } catch (error) {
            apiLevel = -1
        }
    }
    return apiLevel
}
window.tt = {
    sdk: {
        apiLevel: getApiLevel(),
        canIUse: function (name) {
            return true
        }
    },
    System: {
        getSystemInfoSync: function () {
            return TTJSBridge.invoke("tgame_system", "getSystemInfoSync")
        }
    },
    Network: {
        getNetworkType: function () {
            return TTJSBridge.invoke("tgame_network", "getNetworkType")
        }
    },
    Device: {
        vibrate: function (number) {
            if (typeof (number) != "number") {
                console.error("tt.Device.vibrate: number is not number")
                return
            }
            TTJSBridge.invoke("tgame_device", "vibrate", number)
        }
    },
    GameLife: {
        gameLoading: function (progress) {
            if (typeof (progress) != "number") {
                console.error("tt.GameLife.gameLoading: progress is not number")
                return
            }
            TTJSBridge.invoke("tgame_gamelife", "gameLoading", progress)
        },
        gameLoadSuccess: function () {
            TTJSBridge.invoke("tgame_gamelife", "gameLoadSuccess")
        },
        gameLoadFail: function () {
            TTJSBridge.invoke("tgame_gamelife", "gameLoadFail")
        },
        joinGame: function (gameInfo) {
            TTJSBridge.invoke("tgame_gamelife", "joinGame", gameInfo)
        },
        readyGame: function (gameInfo) {
            TTJSBridge.invoke("tgame_gamelife", "readyGame", gameInfo)
        },
        gameStart: function (gameInfo) {
            TTJSBridge.invoke("tgame_gamelife", "gameStart", gameInfo)
        },
        reportGameResult: function (result) {
            TTJSBridge.invoke("tgame_gamelife", "reportGameResult", result)
        },
        setPresenterRole: function (isPresenter) {
            if (typeof (isPresenter) != "boolean") {
                console.error("tt.GameLife.setPresenterRole: isPresenter is not boolean")
                return
            }
            TTJSBridge.invoke("tgame_gamelife", "setPresenterRole", isPresenter)
        }
    },
    User: {
        login: function (cpId, gameId, callback) {
            if (cpId == undefined) {
                console.error("tt.User.login: cpId is undefined")
                return
            }
            if (gameId == undefined) {
                console.error("tt.User.login: gameId is undefined")
                return
            }
            var saveCallback = callbackMap.get("login")
            if (saveCallback != null) {
                console.error("不可以频繁调用login")
                callback(JSON.stringify({
                    ret: -11,
                    msg: "请等待上次login回调调用后再调用login",
                    result: {

                    }
                }))
                return
            }
            callbackMap.set("login", callback)
            TTJSBridge.invoke("tgame_user", "login", JSON.stringify({
                cpId: cpId,
                gameId: gameId
            }), "loginResult")
        },
        getCurrentUserInfo: function (callback) {
            var saveCallback = callbackMap.get("getCurrentUserInfo")
            if (saveCallback != null) {
                console.error("不可以频繁调用getCurrentUserInfo")
                callback(JSON.stringify({
                    ret: -11,
                    msg: "请等待上次getCurrentUserInfo回调调用后再调用getCurrentUserInfo",
                    result: {

                    }
                }))
                return
            }
            callbackMap.set("getCurrentUserInfo", callback)
            TTJSBridge.invoke("tgame_user", "getCurrentUserInfo", "", "getCurrentUserInfoResult")
        },
        setUserValidatedInfo: function (info) {
            TTJSBridge.invoke("tgame_user", "setUserValidatedInfo", info)
        },
        getMic: function (callback) {
            var saveCallback = callbackMap.get("getMic")
            if (saveCallback != null) {
                console.error("不可以频繁调用getMic")
                callback(JSON.stringify({
                    ret: -11,
                    msg: "请等待上次getMic回调调用后再调用getMic",
                    result: {

                    }
                }))
                return
            }
            callbackMap.set("getMic", callback)
            TTJSBridge.invoke("tgame_user", "getMic", "", "getMicResult")
        },
        getMyMicInfo: function(){
            return TTJSBridge.invoke("tgame_user", "getMyMicInfo")
        }
    },
    UI: {
        showToast: function (content) {
            if (typeof (content) != 'string') {
                console.error("tt.UI.showToast: content is not string")
                return
            }
            TTJSBridge.invoke("tgame_ui", "showToast", content)
        }
    }
}

function loginResult(result) {
    var saveCallback = callbackMap.get("login")
    if (saveCallback != null) {
        callbackMap.delete("login")
        saveCallback(result)
    }
}

function getCurrentUserInfoResult(result) {
    var saveCallback = callbackMap.get("getCurrentUserInfo")
    if (saveCallback != null) {
        callbackMap.delete("getCurrentUserInfo")
        saveCallback(result)
    }
}

function getMicResult(result) {
    var saveCallback = callbackMap.get("getMic")
    if (saveCallback != null) {
        callbackMap.delete("getMic")
        saveCallback(result)
    }
}

function onChangePermissions(permissionInfo) {
    if (tt.User.onChangePermissions != undefined) {
        tt.User.onChangePermissions(permissionInfo)
    }
}

function onGameToReady() {
    if (tt.GameLife.onGameToReady != undefined) {
        tt.GameLife.onGameToReady()
    }
}

function onNetworkStatusChange(networkInfo) {
    if (tt.Network.onNetworkStatusChange != undefined) {
        tt.Network.onNetworkStatusChange(networkInfo)
    }
}

function onShow() {
    if (tt.GameLife.onShow != undefined) {
        tt.GameLife.onShow()
    }
}

function onHide() {
    if (tt.GameLife.onHide != undefined) {
        tt.GameLife.onHide()
    }
}

function onUserTalkingChange(talkingInfo){
    if (tt.User.onUserTalkingChange != undefined) {
        tt.User.onUserTalkingChange(talkingInfo)
    }
}